@@ -2,8 +2,12 @@
 #' IsothermalGrowth class
 #' 
 #' @description 
-#' The \code{IsothermalGrowth} class contains the results of a growth prediction
-#' under isothermal conditions. Its constructor is \code{\link{predict_isothermal_growth}}.
+#' `r lifecycle::badge("superseded")`
+#' 
+#' The class [IsothermalGrowth] has been superseded by the top-level
+#' class [GrowthPrediction], which provides a unified approach for growth modelling.
+#' 
+#' Still, it is still returned if the superseded [predict_isothermal_growth()] is called.
 #' 
 #' It is a subclass of list with the items:
 #' \itemize{
@@ -18,7 +22,7 @@ NULL
 
 #' @describeIn IsothermalGrowth print of the model
 #' 
-#' @param x An instance of \code{IsothermalGrowth}.
+#' @param x An instance of `IsothermalGrowth`.
 #' @param ... ignored
 #' 
 #' @export
@@ -32,19 +36,31 @@ print.IsothermalGrowth <- function(x, ...) {
     cat("Parameters of the primary model:\n")
     print(unlist(x$pars))
     
+    logbase <- x$logbase_mu
+    
+    if ( abs(logbase - exp(1)) < .1 ) {
+        logbase <- "e"
+    }
+    cat("\n")
+    cat(paste0("Parameter mu defined in log-", logbase, " scale"))
+    
 }
 
 #' @describeIn IsothermalGrowth plot of the predicted growth curve.
 #'
-#' @param x The object of class \code{IsothermalGrowth} to plot.
+#' @param x The object of class [IsothermalGrowth] to plot.
 #' @param y ignored
 #' @param ... ignored.
 #' @param line_col Aesthetic parameter to change the colour of the line,
-#' see: \code{\link{geom_line}}
+#' see: [geom_line()]
 #' @param line_size Aesthetic parameter to change the thickness of the line,
-#' see: \code{\link{geom_line}}
+#' see: [geom_line()]
 #' @param line_type Aesthetic parameter to change the type of the line,
-#' takes numbers (1-6) or strings ("solid") see: \code{\link{geom_line}}
+#' takes numbers (1-6) or strings ("solid") see: [geom_line()]
+#' @param label_x Title of the x-axis
+#' @param label_y Title of the y-axis
+#' @param ylims Two-dimensional numeric vector with the limits of the y-axis
+#' (or `NULL`, which is the default)
 #'
 #' @export
 #'
@@ -55,17 +71,36 @@ print.IsothermalGrowth <- function(x, ...) {
 plot.IsothermalGrowth <- function(x, y=NULL, ...,
                                   line_col = "black",
                                   line_size = 1,
-                                  line_type = "solid") {
-    
+                                  line_type = "solid",
+                                  ylims = NULL,
+                                  label_y = NULL,
+                                  label_x = "time") {
+
     ggplot(x$simulation) +
         geom_line(aes(x = .data$time, y = .data$logN),
                   col = line_col,
                   size = line_size,
                   linetype = line_type) +
+        scale_y_continuous(limits = ylims,
+                           name = label_y) +
+        xlab(label_x) +
         theme_cowplot()
     
 }
 
+#' @describeIn IsothermalGrowth coefficients of the model
+#' 
+#' @param object an instance of [IsothermalGrowth]
+#' @param ... ignored
+#' 
+#' @export
+#' 
+coef.IsothermalGrowth <- function(object, ...) {
+    
+    unlist(object$pars)
+    
+}
+
 
 
 
@@ -83,4 +118,3 @@ plot.IsothermalGrowth <- function(x, y=NULL, ...,
 
 
 
-
